==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AXorBinop.h <==
// public final class soot.jimple.parser.node.AXorBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4219d25ea1ecea90 soot_jimple_parser_node_AXorBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AXorBinop_H_
#define _JC_soot_jimple_parser_node_AXorBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TXor$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AXorBinop$sub_refs	_jc_soot_jimple_parser_node_AXorBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$refs	_jc_soot_jimple_parser_node_AXorBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$nonrefs	_jc_soot_jimple_parser_node_AXorBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$object	_jc_soot_jimple_parser_node_AXorBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AXorBinop$vmethods	_jc_soot_jimple_parser_node_AXorBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AXorBinop$vtable	_jc_soot_jimple_parser_node_AXorBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AXorBinop$vtype	_jc_soot_jimple_parser_node_AXorBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AXorBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);
extern void _jc_soot_jimple_parser_node_AXorBinop$method$_init$5bd3f77f8cd1caea(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_TXor$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AXorBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AXorBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);
extern struct _jc_soot_jimple_parser_node_TXor$object *_jc_soot_jimple_parser_node_AXorBinop$method$getXor$7a2f679f00c256b5(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);
extern void _jc_soot_jimple_parser_node_AXorBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AXorBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AXorBinop$method$setXor$01a563c3d10635e0(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_TXor$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AXorBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$getXor$7a2f679f00c256b5;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$setXor$01a563c3d10635e0;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AXorBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);
	struct _jc_soot_jimple_parser_node_TXor$object	*(*getXor$7a2f679f00c256b5)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setXor$01a563c3d10635e0)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_TXor$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AXorBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AXorBinop$vmethods	soot_jimple_parser_node_AXorBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AXorBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AXorBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AXorBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TXor$object	*__5fxor__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AXorBinop$refs {
    _jc_soot_jimple_parser_node_AXorBinop$sub_refs	soot_jimple_parser_node_AXorBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AXorBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs	soot_jimple_parser_node_AXorBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AXorBinop$object {
	_jc_soot_jimple_parser_node_AXorBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AXorBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AXorBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AXorBinop$vtype _jc_soot_jimple_parser_node_AXorBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AXorBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AXorBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AXorBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AXorBinop.h <==
// public final class soot.jimple.parser.node.AXorBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4219d25ea1ecea90 soot_jimple_parser_node_AXorBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AXorBinop_H_
#define _JC_soot_jimple_parser_node_AXorBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TXor$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AXorBinop$sub_refs	_jc_soot_jimple_parser_node_AXorBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$refs	_jc_soot_jimple_parser_node_AXorBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$nonrefs	_jc_soot_jimple_parser_node_AXorBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AXorBinop$object	_jc_soot_jimple_parser_node_AXorBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AXorBinop$vmethods	_jc_soot_jimple_parser_node_AXorBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AXorBinop$vtable	_jc_soot_jimple_parser_node_AXorBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AXorBinop$vtype	_jc_soot_jimple_parser_node_AXorBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AXorBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AXorBinop$method$_init$5bd3f77f8cd1caea(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_TXor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AXorBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AXorBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TXor$object *_jc_soot_jimple_parser_node_AXorBinop$method$getXor$7a2f679f00c256b5(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AXorBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AXorBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AXorBinop$method$setXor$01a563c3d10635e0(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_TXor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AXorBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$getXor$7a2f679f00c256b5;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$setXor$01a563c3d10635e0;
extern _jc_method _jc_soot_jimple_parser_node_AXorBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AXorBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TXor$object	*(*getXor$7a2f679f00c256b5)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setXor$01a563c3d10635e0)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *, struct _jc_soot_jimple_parser_node_TXor$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AXorBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AXorBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AXorBinop$vmethods	soot_jimple_parser_node_AXorBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AXorBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AXorBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AXorBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TXor$object	*__5fxor__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AXorBinop$refs {
    _jc_soot_jimple_parser_node_AXorBinop$sub_refs	soot_jimple_parser_node_AXorBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AXorBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AXorBinop$sub_nonrefs	soot_jimple_parser_node_AXorBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AXorBinop$object {
	_jc_soot_jimple_parser_node_AXorBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AXorBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AXorBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AXorBinop$vtype _jc_soot_jimple_parser_node_AXorBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AXorBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AXorBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AXorBinop_H_ */
